# coding: utf-8

"""
    virusapi

    The Cloudmersive Virus Scan API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_virus_api_client
from cloudmersive_virus_api_client.api.scan_cloud_storage_api import ScanCloudStorageApi  # noqa: E501
from cloudmersive_virus_api_client.rest import ApiException


class TestScanCloudStorageApi(unittest.TestCase):
    """ScanCloudStorageApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_virus_api_client.api.scan_cloud_storage_api.ScanCloudStorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_scan_cloud_storage_scan_aws_s3_file(self):
        """Test case for scan_cloud_storage_scan_aws_s3_file

        Scan an AWS S3 file for viruses  # noqa: E501
        """
        pass

    def test_scan_cloud_storage_scan_azure_blob(self):
        """Test case for scan_cloud_storage_scan_azure_blob

        Scan an Azure Blob for viruses  # noqa: E501
        """
        pass

    def test_scan_cloud_storage_scan_gcp_storage_file(self):
        """Test case for scan_cloud_storage_scan_gcp_storage_file

        Scan an Google Cloud Platform (GCP) Storage file for viruses  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
