from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cloudmersive_virus_api_client.api.scan_api import ScanApi
from cloudmersive_virus_api_client.api.scan_cloud_storage_api import ScanCloudStorageApi
