# coding: utf-8

"""
    virusapi

    Virus API lets you scan files and content for viruses and identify security issues with content.  # noqa: E501

    OpenAPI spec version: v1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cloudmersive_virus_api_client
from cloudmersive_virus_api_client.api.scan_api import ScanApi  # noqa: E501
from cloudmersive_virus_api_client.rest import ApiException


class TestScanApi(unittest.TestCase):
    """ScanApi unit test stubs"""

    def setUp(self):
        self.api = cloudmersive_virus_api_client.api.scan_api.ScanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_scan_file(self):
        """Test case for scan_file

        Scan a file for viruses  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
